/**	
*	@file	ColourGenerator.java
*	@author	Ellis James
*	@date	21 Mar 2013
*	@see	Chart
*	
*	@brief 	ColourGenerator generates colours to be stored in an ColourList 
*
*	ColourGenerator generates a colour then it returns the colour.
*
*/



import java.util.Random;
import java.awt.Color;

public class ColourGenerator {
	public static final String	BOCLASH = "C_BOCLASH",
								COLD = "C_COLD",
								GREYSCALE = "C_GREYSCALE",
								PYCLASH = "C_PYCLASH",
								RANDOM = "C_RANDOM",
								WARM = "C_WARM",
								NEON = "C_NEON",
								HCONTRAST = "C_HCONTRAST",
								USER = "C_USERDEFINED";;
	static int m_redVal = 0;
	static int m_greVal = 0;
	static int m_bluVal = 0;
	static Random m_rand = new Random();	
		
	/**
	* This method returns the colour, dependant on which string has been passed
	* to this class.
	*
	* @param colourScheme is the string where the colours generated are stored.
	*
	* @return the colour which corresponds to the string passed.
	*/
	
	public static Color GetColour(String colourScheme) {
		switch (colourScheme) {
			case BOCLASH:  	return Boclash();
			case COLD:  	return Cool();
			case GREYSCALE:	return Greyscale();
			case HCONTRAST:	return Hcontrast();
			case NEON:		return Neon();
			case PYCLASH:  	return Pyclash();
			case RANDOM:  	return Random();
			case WARM:  	return Warm();
		}
		return Color.BLACK;
	}
	
	/**
	* This method returns the blue and orange colours, generated from blue and
	* oranage sets of RGB values.
	*
	* @return the colour which corresponds to the generated RGB values.
	*/
	
	public static Color Boclash() {
	
		int colourRand = m_rand.nextInt(2);
		
		if (colourRand == 0) {
			m_redVal = m_rand.nextInt(50);
			m_greVal = m_rand.nextInt(50);
			m_bluVal = m_rand.nextInt(55)+200;
		} else if (colourRand == 1) {
			m_redVal = m_rand.nextInt(10)+240;
			m_greVal = m_rand.nextInt(20)+120;
			m_bluVal = m_rand.nextInt(5);
		}
		System.out.println("Colour Generation - Red: " + m_redVal +
		", Green: " + m_greVal + ", Blue: " + m_bluVal);
		Color BoclashColour = new Color(m_redVal, m_greVal, m_bluVal);

		return BoclashColour;
	}
	
	/**
	* This method returns the colour, generated from a "cool" set of RGB values.
	*
	* @return the colour which corresponds to the generated RGB values.
	*/
	
	public static Color Cool() {
	
		int colourRand = m_rand.nextInt(3);
		
		if (colourRand == 0) {
			m_redVal = m_rand.nextInt(30);
			m_greVal = m_rand.nextInt(114);
			m_bluVal = m_rand.nextInt(127)+127;
		} else if (colourRand == 1) {
			m_redVal = m_rand.nextInt(155);
			m_greVal = m_rand.nextInt(155)+100;
			m_bluVal = m_rand.nextInt(50);
		} else if (colourRand == 2) {
			m_redVal = m_rand.nextInt(100)+86;
			m_greVal = m_rand.nextInt(115);
			m_bluVal = m_rand.nextInt(100)+155;
		}
		System.out.println("Colour Generation - Red: " + m_redVal +
		", Green: " + m_greVal + ", Blue: " + m_bluVal);
		Color CoolColour = new Color(m_redVal, m_greVal, m_bluVal);

		return CoolColour;
	}
	
	/**
	* This method returns the colour, generated from a "greyscale" 
	* set of RGB values.
	*
	* @return the colour which corresponds to the generated RGB values.
	*/
	
	public static Color Greyscale() {
	
		int colourRand = m_rand.nextInt(3);
		
		if (colourRand == 0) {
			m_redVal = m_rand.nextInt(1)+91;
			m_greVal = m_rand.nextInt(1)+91;
			m_bluVal = m_rand.nextInt(1)+91;
		} else if (colourRand == 1) {
			m_redVal = m_rand.nextInt(1)+79;
			m_greVal = m_rand.nextInt(1)+79;
			m_bluVal = m_rand.nextInt(1)+79;
		} else if (colourRand == 2) {
			m_redVal = m_rand.nextInt(1)+49;
			m_greVal = m_rand.nextInt(1)+49;
			m_bluVal = m_rand.nextInt(1)+49;
		} else if (colourRand == 3) {
			m_redVal = m_rand.nextInt(1)+9;
			m_greVal = m_rand.nextInt(1)+9;
			m_bluVal = m_rand.nextInt(1)+9;
		} else if (colourRand == 4) {
			m_redVal = m_rand.nextInt(1);
			m_greVal = m_rand.nextInt(1);
			m_bluVal = m_rand.nextInt(1);
		}
		System.out.println("Colour Generation - Red: " + m_redVal +
		", Green: " + m_greVal + ", Blue: " + m_bluVal);
		Color GreyscaleColour = new Color(m_redVal, m_greVal, m_bluVal);

		return GreyscaleColour;
	}
	
	/**
	* This method returns the colour, generated from a "Hcontrast" 
	* set of RGB values.
	*
	* @return the colour which corresponds to the generated RGB values.
	*/
	
	public static Color Hcontrast() {
	
		int colourRand = m_rand.nextInt(20);
		
		if (colourRand == 0) {
			m_redVal = m_rand.nextInt(1)+254;
			m_greVal = m_rand.nextInt(1)+23;
			m_bluVal = m_rand.nextInt(1)+114;
		} else if (colourRand == 1) {
			m_redVal = m_rand.nextInt(1)+11;
			m_greVal = m_rand.nextInt(1)+254;
			m_bluVal = m_rand.nextInt(1)+241;
		} else if (colourRand == 2) {
			m_redVal = m_rand.nextInt(1)+254;
			m_greVal = m_rand.nextInt(1)+204;
			m_bluVal = m_rand.nextInt(1)+24;
		} else if (colourRand == 3) {
			m_redVal = m_rand.nextInt(1)+166;
			m_greVal = m_rand.nextInt(1)+86;
			m_bluVal = m_rand.nextInt(1)+170;
		} else if (colourRand == 4) {
			m_redVal = m_rand.nextInt(1)+123;
			m_greVal = m_rand.nextInt(1)+254;
			m_bluVal = m_rand.nextInt(1)+129;
		} else if (colourRand == 5) {
			m_redVal = m_rand.nextInt(1)+254;
			m_greVal = m_rand.nextInt(1)+92;
			m_bluVal = m_rand.nextInt(1)+80;
		} else if (colourRand == 6) {
			m_redVal = m_rand.nextInt(1)+55;
			m_greVal = m_rand.nextInt(1)+197;
			m_bluVal = m_rand.nextInt(1)+225;
		} else if (colourRand == 7) {
			m_redVal = m_rand.nextInt(1)+234;
			m_greVal = m_rand.nextInt(1)+254;
			m_bluVal = m_rand.nextInt(1)+18;
		} else if (colourRand == 8) {
			m_redVal = m_rand.nextInt(1)+235;
			m_greVal = m_rand.nextInt(1)+17;
			m_bluVal = m_rand.nextInt(1)+136;
		} else if (colourRand == 9) {
			m_redVal = m_rand.nextInt(1)+54;
			m_greVal = m_rand.nextInt(1)+254;
			m_bluVal = m_rand.nextInt(1)+198;
		} else if (colourRand == 10) {
			m_redVal = m_rand.nextInt(1)+254;
			m_greVal = m_rand.nextInt(1)+161;
			m_bluVal = m_rand.nextInt(1)+45;
		} else if (colourRand == 11) {
			m_redVal = m_rand.nextInt(1)+124;
			m_greVal = m_rand.nextInt(1)+128;
			m_bluVal = m_rand.nextInt(1)+191;
		} else if (colourRand == 12) {
			m_redVal = m_rand.nextInt(1)+164;
			m_greVal = m_rand.nextInt(1)+254;
			m_bluVal = m_rand.nextInt(1)+87;
		} else if (colourRand == 13) {
			m_redVal = m_rand.nextInt(1)+254;
			m_greVal = m_rand.nextInt(1)+49;
			m_bluVal = m_rand.nextInt(1)+101;
		}  else if (colourRand == 14) {
			m_redVal = m_rand.nextInt(1)+12;
			m_greVal = m_rand.nextInt(1)+240;
			m_bluVal = m_rand.nextInt(1)+247;
		} else if (colourRand == 15) {
			m_redVal = m_rand.nextInt(1)+254;
			m_greVal = m_rand.nextInt(1)+230;
			m_bluVal = m_rand.nextInt(1)+10;
		} else if (colourRand == 16) {
			m_redVal = m_rand.nextInt(1)+193;
			m_greVal = m_rand.nextInt(1)+59;
			m_bluVal = m_rand.nextInt(1)+157;
		} else if (colourRand == 17) {
			m_redVal = m_rand.nextInt(1)+96;
			m_greVal = m_rand.nextInt(1)+254;
			m_bluVal = m_rand.nextInt(1)+156;
		} else if (colourRand == 18) {
			m_redVal = m_rand.nextInt(1)+254;
			m_greVal = m_rand.nextInt(1)+118;
			m_bluVal = m_rand.nextInt(1)+66;
		} else if (colourRand == 19) {
			m_redVal = m_rand.nextInt(1)+81;
			m_greVal = m_rand.nextInt(1)+171;
			m_bluVal = m_rand.nextInt(1)+212;
		}
		System.out.println("Colour Generation - Red: " + m_redVal +
		", Green: " + m_greVal + ", Blue: " + m_bluVal);
		Color HcontrastColour = new Color(m_redVal, m_greVal, m_bluVal);

		return HcontrastColour;
	}
	
	/**
	* This method returns the colour, generated from a "neon" set of RGB values.
	*
	* @return the colour which corresponds to the generated RGB values.
	*/
	
	public static Color Neon() {
	
		int colourRand = m_rand.nextInt(3);
		
		if (colourRand == 0) {
			m_redVal = m_rand.nextInt(1)+246;
			m_greVal = m_rand.nextInt(1)+155;
			m_bluVal = m_rand.nextInt(1)+66;
		} else if (colourRand == 1) {
			m_redVal = m_rand.nextInt(1)+250;
			m_greVal = m_rand.nextInt(1)+254;
			m_bluVal = m_rand.nextInt(1)+37;
		} else if (colourRand == 2) {
			m_redVal = m_rand.nextInt(1)+123;
			m_greVal = m_rand.nextInt(1)+225;
			m_bluVal = m_rand.nextInt(1)+84;
		} else if (colourRand == 3) {
			m_redVal = m_rand.nextInt(1)+53;
			m_greVal = m_rand.nextInt(1)+175;
			m_bluVal = m_rand.nextInt(1)+196;
		} else if (colourRand == 4) {
			m_redVal = m_rand.nextInt(1)+235;
			m_greVal = m_rand.nextInt(1)+81;
			m_bluVal = m_rand.nextInt(1)+133;
		} else if (colourRand == 5) {
			m_redVal = m_rand.nextInt(1)+177;
			m_greVal = m_rand.nextInt(1)+65;
			m_bluVal = m_rand.nextInt(1)+149;
		} else if (colourRand == 6) {
			m_redVal = m_rand.nextInt(1)+244;
			m_greVal = m_rand.nextInt(1)+20;
			m_bluVal = m_rand.nextInt(1)+72;
		} else if (colourRand == 7) {
			m_redVal = m_rand.nextInt(1)+253;
			m_greVal = m_rand.nextInt(1)+132;
			m_bluVal = m_rand.nextInt(1)+51;
		} else if (colourRand == 8) {
			m_redVal = m_rand.nextInt(1)+83;
			m_greVal = m_rand.nextInt(1)+183;
			m_bluVal = m_rand.nextInt(1)+69;
		} else if (colourRand == 9) {
			m_redVal = m_rand.nextInt(1)+63;
			m_greVal = m_rand.nextInt(1)+173;
			m_bluVal = m_rand.nextInt(1)+200;
		}
		System.out.println("Colour Generation - Red: " + m_redVal +
		", Green: " + m_greVal + ", Blue: " + m_bluVal);
		Color NeonColour = new Color(m_redVal, m_greVal, m_bluVal);

		return NeonColour;
	}
	
	/**
	* This method returns the purple and yellow colours, generated from purple
	* and yellow sets of RGB values.
	*
	* @return the colour which corresponds to the generated RGB values.
	*/
	
	public static Color Pyclash() {
	
		int colourRand = m_rand.nextInt(2);
		
		if (colourRand == 0) {
			m_redVal = m_rand.nextInt(10)+120;
			m_greVal = m_rand.nextInt(2);
			m_bluVal = m_rand.nextInt(10)+120;
		} else if (colourRand == 1) {
			m_redVal = m_rand.nextInt(10)+240;
			m_greVal = m_rand.nextInt(10)+240;
			m_bluVal = m_rand.nextInt(5);
		}
		System.out.println("Colour Generation - Red: " + m_redVal +
		", Green: " + m_greVal + ", Blue: " + m_bluVal);
		Color PyclashColour = new Color(m_redVal, m_greVal, m_bluVal);

		return PyclashColour;
	}
	
	/**
	* This method returns the colour, generated from a random set of RGB values.
	*
	* @return the colour which corresponds to the generated RGB values.
	*/

	public static Color Random() {
		m_redVal = m_rand.nextInt(255);
		m_greVal = m_rand.nextInt(255);
		m_bluVal = m_rand.nextInt(255);
		System.out.println("Colour Generation - Red: " + m_redVal +
		", Green: " + m_greVal + ", Blue: " + m_bluVal);
		Color RandomColour = new Color(m_redVal, m_greVal, m_bluVal);
		
		return RandomColour;
	}
	
	/**
	* This method returns the colour, generated from a "warm" set of RGB values.
	*
	* @return the colour which corresponds to the generated RGB values.
	*/	
	
	public static Color Warm() {	
		int colourRand = m_rand.nextInt(3);	 
		if (colourRand == 0) {
			m_redVal = m_rand.nextInt(127)+127;
			m_greVal = m_rand.nextInt(42);
			m_bluVal = m_rand.nextInt(60);
		} else if (colourRand == 1) {
			m_redVal = m_rand.nextInt(40)+215;
			m_greVal = m_rand.nextInt(65)+100;
			m_bluVal = 0;
		} else if (colourRand == 2) {
			m_redVal = m_rand.nextInt(40)+215;
			m_greVal = m_rand.nextInt(40)+215;
			m_bluVal = 0;
		}
		System.out.println("Colour Generation - Red: " + m_redVal +
		", Green: " + m_greVal + ", Blue: " + m_bluVal);
		Color WarmColour = new Color(m_redVal, m_greVal, m_bluVal);

		return WarmColour;
	}
}