/**	
*	@file	GUI.java
*	@author	Tim Connolly - Callum Massey A6
*	@date	14/04/13
*	@see	TypeChooser, ColourSchemeChooser, Table, Chart, CSV, ChartData
*
*	@brief	GUI class creates the GUI.
*	
*	GUI creates a JFrame, adds the components and runs the program
*	by the main method. 	
*/




import javax.swing.JFrame;
import javax.swing.JMenuBar;
import javax.swing.JMenu;
import javax.swing.JMenuItem;
import javax.swing.SwingUtilities;
import javax.swing.ImageIcon;
import javax.swing.JToolBar;
import javax.swing.JButton;
import javax.swing.JSplitPane;
import javax.swing.JTable;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JOptionPane;
import javax.swing.JFileChooser;
import javax.swing.filechooser.FileFilter;
import javax.swing.JLabel;
import javax.swing.JTextField;
import javax.swing.JDialog;

import java.awt.image.BufferedImage;
import java.awt.GridLayout;
import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.Color;
import java.awt.Component;
import java.awt.Dimension;

import org.jfree.chart.ChartPanel;

import java.io.File;
import java.io.RandomAccessFile;
import java.io.FileNotFoundException;
import java.io.IOException;

import java.util.ArrayList;

import javax.imageio.ImageIO;


/**	
*	GUI class, creates the GUI making a JFrame visible and adding
*	the different components to the frame.
*/
public class GUI extends JFrame {	
	private JToolBar m_ToolBar;
	private JButton m_ImpButton, m_ExpButton, m_TypeButton, m_ColourButton,
			m_EditButton, m_OkButton, m_SlideShowButton, m_PauseButton;
	private JScrollPane m_ScrollPanel;
	private JTextField m_XAxisField, m_YAxisField, m_TitleField, 
			m_DescriptionField,	m_AuthorField;
	private JLabel m_XAxisLabel, m_YAxisLabel, m_TitleLabel, m_DescriptionLabel, 
			m_AuthorLabel, m_DateLabel;
	private JSplitPane m_Splitpane;
	private JSplitPane m_SplitpaneLeft;
	private JSplitPane m_SplitpaneChart;
	private JTable m_DataTable;
	private JTable m_DataTableLeft;
	private JPanel m_SettingsPanel;
	private JFileChooser m_FileChooser;
	private ChartPanel m_ChartPanel;
	private ChartPanel m_ChartPanelBottom;
	private GUI m_Current;
	private Boolean Paused = false;
	private JDialog m_ColourDialog, m_ChartDialog;
	private int DEFAULT_SLIDER_POSITION = 900; 
	private int DEFAULT_SLIDER_POSITION_LEFT = 300; 
	private int DEFAULT_SLIDER_POSITION_CHART = 250; 
	private int Interval = 5;
	private String[][] m_TableData;
	private String[] m_TableHeadings;
	private String[][] m_TableDataLeft;
	private String[] m_TableHeadingsLeft;
	private String m_ChosenScheme = null;
	private ArrayList<Color> m_UserDefinedColourList;
	private Chart m_Chart;
	private Chart m_ChartBottom;
	final int CHART_DIALOG_WIDTH = 850;
	final int CHART_DIALOG_HEIGHT = 450;
	final int COLOUR_DIALOG_WIDTH = 600;
	final int COLOUR_DIALOG_HEIGHT = 480;

	/**
	*	@return m_TableHeadings - returns the headings for the columns in the,
	*							 table
	*/
	public String[] GetTableHeadings(){
		return m_TableHeadings;
	}
	
	/**
	*	@return m_TableData - returns the data for the table
	*/
	public String[][] GetTableData(){
		return m_TableData;
	}	
	/**
	*	@return m_TableHeadingsLeft - returns the headings for the columns in the,
	*							 table
	*/
	public String[] GetTableHeadingsLeft(){
		return m_TableHeadingsLeft;
	}
	
	/**
	*	@return m_TableDataLeft - returns the data for the table
	*/
	public String[][] GetTableDataLeft(){
		return m_TableDataLeft;
	}	
	
	/**
	*	@return m_ChosenScheme - returns the currently selected colour scheme
	*/
	public String GetColourScheme(){
		return m_ChosenScheme;
	}		
	
	/**
	*	@return m_Chart - returns the Chart
	*/
	public Chart GetChart(){
		return m_Chart;
	}
	/**
	*	@return m_Chartbottom - returns the Chart
	*/
	public Chart GetChartBottom(){
		return m_ChartBottom;
	}
	
	/**
	*	@return m_Titlefield - returns the title for the chart
	*/
	public String GetHostTitle(){
		return m_TitleField.getText();
	}
	
	/**
	*	@return m_AuthorField - returns the Author for the chart
	*/
	public String GetHostAuthor(){
		return m_AuthorField.getText();
	}
	
	/**
	*	@return m_XAxisField - returns the X Axis title for the chart
	*/
	public String GetHostXAxis(){
		return m_XAxisField.getText();
	}
	
	/**
	*	@return m_YAxisField - returns the Y Axis title for the chart 
	*/
	public String GetHostYAxis(){
		return m_YAxisField.getText();
	}
	
	/**
	*	@return m_DescriptionField - returns the Description of the graph
	*/
	public String GetHostDescr(){
		return m_DescriptionField.getText();
	}
	
	/**
	*	@return ChartData - uses user selected rows and colums to return the 
	*						data that charts use
	*/
	public ChartData GetSelectedTableData(){
		int[] selectedColumns = m_DataTable.getSelectedColumns();
		int[] selectedRows = m_DataTable.getSelectedRows();
				
		String[] headingsSelected = new String[selectedColumns.length];
		String[][] rowsSelected = new String[selectedColumns.length]
												[selectedRows.length];		

		for (int i = 0; i < headingsSelected.length;i++){	
			headingsSelected[i] = m_TableHeadings[selectedColumns[i]];
			for (int j = 0; j < selectedRows.length;j++){		
				rowsSelected[i][j] = m_DataTable.getValueAt(selectedRows[j],
												selectedColumns[i]).toString();
			}
		}	

		return (new ChartData(headingsSelected,rowsSelected));
	}
	/**
	*	@return ChartData - uses user selected rows and colums to return the 
	*						data that charts use
	*/
	public ChartData GetSelectedTableDataLeft(){
		int[] selectedColumns = m_DataTableLeft.getSelectedColumns();
		int[] selectedRows = m_DataTableLeft.getSelectedRows();
				
		String[] headingsSelected = new String[selectedColumns.length];
		String[][] rowsSelected = new String[selectedColumns.length]
												[selectedRows.length];		

		for (int i = 0; i < headingsSelected.length;i++){	
			headingsSelected[i] = m_TableHeadingsLeft[selectedColumns[i]];
			for (int j = 0; j < selectedRows.length;j++){		
				rowsSelected[i][j] = m_DataTableLeft.getValueAt(selectedRows[j],
												selectedColumns[i]).toString();
			}
		}	

		return (new ChartData(headingsSelected,rowsSelected));
	}
	
	/**
	*	@return m_UserDefinedColourList - returns the user defined colour list
	*/
	public ArrayList<Color> GetUserDefinedScheme(){
		return m_UserDefinedColourList;
	}
	
	/**
	*	@param title - sets the Title of the chart
	*/
	public void SetHostTitle(String title){
		m_TitleField.setText(title);
	}
	
	/**
	*	@param author - sets the author of the chart
	*/
	public void SetHostAuthor(String author){
		m_AuthorField.setText(author);
	}
	
	/**
	*	@param xAxis  - sets the x Axis label
	*/
	public void SetHostXAxis(String xAxis){
		m_XAxisField.setText(xAxis);
	}
	
	/**
	*	@param yAxis  - sets the y Axis label
	*/
	public void SetHostYAxis(String yAxis){
		m_YAxisField.setText(yAxis);
	}
	
	/**
	*	@param descr - sets the description of the chart
	*/
	public void SetHostDescr(String descr){
		m_DescriptionField.setText(descr);
	}	
	
	/**
	*	@param chart - sets the current chart
	*/
	public void SetChart(Chart chart){
		m_Chart = chart;
	}	
	/**
	*	@param chartBotttom - sets the current chart
	*/
	public void SetChartBottom(Chart chart){
		m_ChartBottom = chart;
	}
	
	/**
	*	@param userList - sets the user defined colour list
	*/
	public void SetUserColourScheme(ArrayList<Color> userList){
		m_UserDefinedColourList = userList;
	}
	
	/**
	*	@param chosenScheme - sets the colour scheme
	*/
	public void SetColourScheme(String chosenScheme){
		m_ChosenScheme = chosenScheme;	
	}
	
	/**
	*	@param headings - sets the coloum titles
	*/
	public void SetTableHeadings(String[] headings){
		m_TableHeadings = headings;
	}
	
	/**
	*	@param tableData - sets the data for the table
	*/
	public void SetTableData(String[][] tableData){
		m_TableData = tableData;
	}
	/**
	*	@param headings - sets the coloum titles
	*/
	public void SetTableHeadingsLeft(String[] headings){
		m_TableHeadingsLeft = headings;
	}
	
	/**
	*	@param tableData - sets the data for the table
	*/
	public void SetTableDataLeft(String[][] tableData){
		m_TableDataLeft = tableData;
	}
	
	/**
	*	@param createdChart - sets the chart on the left panel and refreshes the
	*						  GUI
	*/
	public void SetChartOnPanel(Chart createdChart){
		if (GetM_ChartPanel().getComponents().length > 0) {
			GetM_ChartPanel().removeAll();
		}		
		m_Chart = createdChart;
		GetM_ChartPanel().setChart(createdChart.GetChart());
		GetM_ChartPanel().updateUI();
	}
	public void SetChartOnPanelBottom(Chart createdChart){
		if (GetM_ChartPanelBottom().getComponents().length > 0) {
			GetM_ChartPanelBottom().removeAll();
		}		
		m_ChartBottom = createdChart;
		GetM_ChartPanelBottom().setChart(createdChart.GetChart());
		GetM_ChartPanelBottom().updateUI();
	}
	
	/**
	*	@param axisEditable - sets the editable preferences enabling the
	*						  settings panel and ok button and refreshing the UI
	*/
	public void SetOptionsOnToolbar(Boolean axisEditable){
		if (m_ToolBar.getComponents().length > 7) {
				m_ToolBar.remove(m_OkButton);
				m_ToolBar.remove(m_ScrollPanel);				
				m_ToolBar.updateUI();
		}
		m_SettingsPanel.setVisible(true);
		m_OkButton.setVisible(true);	
		m_ExpButton.setEnabled(true);
		m_ToolBar.add(m_ScrollPanel);	
		m_ToolBar.add(m_OkButton);		
		m_XAxisField.setEnabled(axisEditable);
		m_YAxisField.setEnabled(axisEditable);
		m_ToolBar.updateUI();
	}
	
	/**
	*	clears the editbale settings for the charts
	*/
	public void ClearSettings(){
		SetHostTitle("");
		SetHostAuthor("");
		SetHostXAxis("");
		SetHostYAxis("");
		SetHostDescr("");
	}	
	
	/**
	*	closes the chart type chooser pop out
	*/
	public void closeChartDialog(){
		m_ChartDialog.dispose();
	}
	
	/**
	*	closes the colour chooser pop out
	*/
	public void closeColourDialog(){
		m_ColourDialog.dispose();
	}
	
	/**
	*	constructs a GUI using initComponents	
	*/
	public GUI(){
		initComponents();
		m_Current = this;
	}
	
	
	/**
	*	main method creates a new GUI and sets it visible
	*/
	public static void main(String[] args){
		SwingUtilities.invokeLater(new Runnable(){
			public void run(){
				new GUI().setVisible(true);
			}
		});
	}
	
	/**
	*	checks whether a chart is there which can be exported. Asks the user
	*	what type of image file they would like to save, either png or gif.
	*	saves the chart in the selected type within the directory.
	*/
	private void exportToFile(){		
		Object[] options = {".png",".gif"};
		int extensionChosen = JOptionPane.showOptionDialog(null,
				"Save chart as PNG or GIF",	null,
				JOptionPane.YES_NO_CANCEL_OPTION, 
				JOptionPane.QUESTION_MESSAGE,null, options,options[0]);		
		String extension = ".png";
		switch (extensionChosen){
			case 0: extension = ".png";
			case 1: extension = ".gif";
		}
		BufferedImage chartForOutput 
				= GetM_ChartPanel().getChart().createBufferedImage(
				GetM_ChartPanel().getWidth(), GetM_ChartPanel().getHeight());
		try {
			File outputFile = new File("Chart " + System.currentTimeMillis() + 
											extension);			
			if (extension.equals(".png")){
				ImageIO.write(chartForOutput, "png", outputFile);
			} else if (extension.equals(".gif")){
				ImageIO.write(chartForOutput, "gif", outputFile);
			}
		} catch(IOException e2){
			JOptionPane.showMessageDialog(null, "Unable to save file.");
		}
	}
	
	/**
	*	opens a file chooser to select a csv file.
	*	seperates the values and imports the file into the table as selectable
	*	data
	*/
	private void importFromFile(){
		Boolean imported = false;
		File CSVFile = new File("csv/coalDisasters.csv");
		m_FileChooser = new JFileChooser();
		m_FileChooser.setAcceptAllFileFilterUsed(false);
		m_FileChooser.setFileFilter(new FileFilter() {
			public boolean accept(File f) {
				return f.getName().toLowerCase().endsWith(".csv")||f.isDirectory();
			}
			public String getDescription() {
				return "CSV Files (Comma Separated Values)";
			}
		});
		int returnValue = m_FileChooser.showOpenDialog(null);
		if (returnValue == JFileChooser.APPROVE_OPTION) {					
				CSVFile = m_FileChooser.getSelectedFile();
				CSV importer = new CSV(m_Current);
				importer.ImportCSVFile(CSVFile);
				imported = true;
		}
		
		if (imported){
			Table TablePopulator = new Table(m_Current);
			m_DataTable = new JTable(TablePopulator.PopulateTable(m_TableData,
			m_TableHeadings));
			m_DataTable.setColumnSelectionAllowed(true);
			JScrollPane m_TableScrollPane = new JScrollPane(m_DataTable);
			m_Splitpane.setRightComponent(m_TableScrollPane);
			m_Splitpane.setDividerLocation(DEFAULT_SLIDER_POSITION);
			m_SplitpaneChart.setDividerLocation(DEFAULT_SLIDER_POSITION_CHART);
			m_SplitpaneLeft.setDividerLocation(DEFAULT_SLIDER_POSITION_LEFT);
			m_TypeButton.setEnabled(true);
			m_ColourButton.setEnabled(true);
		}
		
	}
	
	/**
	*	opens a file chooser to select a csv file.
	*	seperates the values and imports the file into the table as selectable
	*	data
	*/
	private void importFromFileLeft(){
		Boolean imported = false;
		File CSVFile = new File("csv/coalDisasters.csv");
		m_FileChooser = new JFileChooser();
		m_FileChooser.setAcceptAllFileFilterUsed(false);
		m_FileChooser.setFileFilter(new FileFilter() {
			public boolean accept(File f) {
				return f.getName().toLowerCase().endsWith(".csv")||f.isDirectory();
			}
			public String getDescription() {
				return "CSV Files (Comma Separated Values)";
			}
		});
		int returnValue = m_FileChooser.showOpenDialog(null);
		if (returnValue == JFileChooser.APPROVE_OPTION) {					
				CSVFile = m_FileChooser.getSelectedFile();
				CSV importer = new CSV(m_Current);
				importer.ImportCSVFileLeft(CSVFile);
				imported = true;
		}
		
		if (imported){
			Table TablePopulator = new Table(m_Current);
			m_DataTableLeft = new JTable(TablePopulator.PopulateTable(m_TableDataLeft,
			m_TableHeadingsLeft));
			m_DataTableLeft.setColumnSelectionAllowed(true);
			JScrollPane m_TableScrollPane = new JScrollPane(m_DataTableLeft);
			m_SplitpaneLeft.setLeftComponent(m_TableScrollPane);
			m_Splitpane.setDividerLocation(DEFAULT_SLIDER_POSITION);
			m_SplitpaneChart.setDividerLocation(DEFAULT_SLIDER_POSITION_CHART);
			m_SplitpaneLeft.setDividerLocation(DEFAULT_SLIDER_POSITION_LEFT);
			m_TypeButton.setEnabled(true);
			m_ColourButton.setEnabled(true);
		}
		
	}
	
	/**
	*	creates new buttons using image icons and creates an action listener for
	*	each to add individual functionality.
	*/
	private void initButtons(){
	//	ClassLoader cldr = this.getClass().getClassLoader();
		m_ImpButton = new JButton(new ImageIcon(ClassLoader.getSystemResource("import_icon.png")));
		m_ImpButton.setToolTipText("Import");
		m_ImpButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				importFromFile();
				//popup yes/no options
				Object[] options = {"Yes","No"};
				int choice = JOptionPane.showOptionDialog(m_Current,"Load Second Data Set?",
						"Load Data", JOptionPane.YES_NO_OPTION,JOptionPane.QUESTION_MESSAGE,
						null,options, options[1]);
				if (choice == 0) {
					importFromFileLeft();
					m_SlideShowButton.setEnabled(true);
				}
			}
		});
		
		m_ExpButton = new JButton(new ImageIcon(ClassLoader.getSystemResource("export_icon.png")));
		m_ExpButton.setToolTipText("Export");
		m_ExpButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent evt) {	
				exportToFile();
			}
		});
		
		m_TypeButton = new JButton(new ImageIcon(ClassLoader.getSystemResource("select_graph.png")));
		m_TypeButton.setToolTipText("Choose Chart Type");
		m_TypeButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent evt) {	
				if (m_DataTable.getSelectedRows().length > 1){
					TypeChooser typeChooser = new TypeChooser(m_Current);	
					m_ChartDialog = new JDialog();	
					m_ChartDialog.setLayout(new BorderLayout());
					m_ChartDialog.setMinimumSize(new Dimension(CHART_DIALOG_WIDTH,
													CHART_DIALOG_HEIGHT));
					m_ChartDialog.add(typeChooser.CreateInterface(),BorderLayout.CENTER);
					m_ChartDialog.setLocationRelativeTo(null);
					m_ChartDialog.setVisible(true);
				} else {
					JOptionPane.showMessageDialog(null, "Please select more than"
													+ " one row of data first");
				}
			}
		});		
		
		m_SlideShowButton = new JButton(new ImageIcon(ClassLoader.getSystemResource("SlideShow.png")));
		m_SlideShowButton.setToolTipText("run Slideshow");
		m_SlideShowButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent evt) {	
				if (m_DataTable.getSelectedRows().length > 1){
					
					String s = (String)JOptionPane.showInputDialog(
					                    m_Current,
					                    "Enter Slide Interval:",
					                    "Interval", JOptionPane.PLAIN_MESSAGE,
					                    null,
					                    null,
					                    "5");

					//If a int was returned, say so.
					if ((s != null) && (s.length() > 0)) {
					    SetInterval(Integer.parseInt(s) * 1000);
						m_PauseButton.setEnabled(true);
						SlideShow slideshow = new SlideShow(m_Current);
						slideshow.start();
					}
					
					
			
				} else {
					JOptionPane.showMessageDialog(null, "Please select more than"
													+ " one row of data first");
				}
			}
		});
		m_PauseButton = new JButton(new ImageIcon(ClassLoader.getSystemResource("pause.png")));
		m_PauseButton.setToolTipText("Pause Button");
		m_PauseButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent evt) {	
				if (Paused == false){
					Paused = true;
				} else {
					Paused = false;
				}
			}
		});
		
		
		m_ColourButton = new JButton(new ImageIcon(ClassLoader.getSystemResource("colour_icon.png")));
		m_ColourButton.setToolTipText("Edit Colour Scheme");
		m_ColourButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent evt) {	
				ColourSchemeChooser colourChooser = new ColourSchemeChooser(m_Current);	
				m_ColourDialog = new JDialog();	
				m_ColourDialog.setLayout(new BorderLayout());
				m_ColourDialog.setMinimumSize(new Dimension(COLOUR_DIALOG_WIDTH,
														COLOUR_DIALOG_HEIGHT));
				m_ColourDialog.add(colourChooser.CreateInterface(),BorderLayout.CENTER);
				m_ColourDialog.setLocationRelativeTo(null);
				m_ColourDialog.setVisible(true);
			}
		});
		
		m_EditButton = new JButton(new ImageIcon(ClassLoader.getSystemResource("edit_icon.png")));
		m_EditButton.setToolTipText("Edit Chart Preferences");
		m_EditButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent evt) {	
				m_SettingsPanel.setVisible(true);
				m_OkButton.setVisible(true);				
				m_ToolBar.add(m_ScrollPanel);	
				m_ToolBar.add(m_OkButton);		
				m_EditButton.setEnabled(false);
				m_ToolBar.updateUI();
			}
		});
		
		m_OkButton = new JButton(new ImageIcon(ClassLoader.getSystemResource("ok_icon.png")));	
		m_OkButton.setVisible(false);
		m_OkButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent evt) {	
				//write new textfield data into the chart
				m_ToolBar.remove(m_OkButton);
				m_ToolBar.remove(m_ScrollPanel);				
				m_ToolBar.updateUI();
				GetChart().SetChartTitle(GetHostTitle());
				GetChart().SetAuthor(GetHostAuthor());
				GetChart().SetXAxis(GetHostXAxis());
				GetChart().SetYAxis(GetHostYAxis());
				GetChart().SetDescription(GetHostDescr());
				SetChartOnPanel(GetChart());
				GetChartBottom().SetChartTitle(GetHostTitle());
				GetChartBottom().SetAuthor(GetHostAuthor());
				GetChartBottom().SetXAxis(GetHostXAxis());
				GetChartBottom().SetYAxis(GetHostYAxis());
				GetChartBottom().SetDescription(GetHostDescr());
				SetChartOnPanelBottom(GetChart());
				m_EditButton.setEnabled(true);
			}
		});
	}
	
	/**
	*	adds the components to the JFrame sets default size and sets visible 
	*	true
	*/
	private void initComponents(){				
		initScrollPanel();	
		initToolBar();		
		SetM_ChartPanel(new ChartPanel(null));
		SetM_ChartPanelBottom(new ChartPanel(null));
		m_DataTable = new JTable();
		m_DataTableLeft = new JTable();
		
		
		m_SplitpaneChart = new JSplitPane(JSplitPane.VERTICAL_SPLIT, GetM_ChartPanel(), 
				GetM_ChartPanelBottom());
		m_SplitpaneLeft = new JSplitPane(JSplitPane.HORIZONTAL_SPLIT, m_DataTableLeft, 
				add(m_SplitpaneChart));
		m_Splitpane = new JSplitPane(JSplitPane.HORIZONTAL_SPLIT, add(m_SplitpaneLeft), 
				m_DataTable);
		
		m_Splitpane.setDividerLocation(DEFAULT_SLIDER_POSITION);
		m_SplitpaneChart.setDividerLocation(DEFAULT_SLIDER_POSITION_CHART);
		m_SplitpaneLeft.setDividerLocation(DEFAULT_SLIDER_POSITION_LEFT);
		add(m_Splitpane);	
	//	ClassLoader cldr = this.getClass().getClassLoader();
		//ImageIcon img = new ImageIcon(cldr.getSystemResource("program_icon.png"));
		//m_Current.setIconImage(img.getImage());
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		setSize(1200,700);
		setTitle("Data Visualisation Software");
		setVisible(true);
		setLocationRelativeTo(null);
	}
	
	/**
	*	adds components to the scroll panel 
	*/
	private void initScrollPanel(){
		m_SettingsPanel = new JPanel();
		m_SettingsPanel.setOpaque(false);
		
		m_TitleField = new JTextField();
		m_AuthorField = new JTextField();
		m_XAxisField = new JTextField();
		m_YAxisField = new JTextField();
		m_DescriptionField = new JTextField();
	
		m_TitleLabel = new JLabel("Title:");
		m_AuthorLabel = new JLabel("Author:");
		m_XAxisLabel = new JLabel("X Axis:");
		m_YAxisLabel = new JLabel("Y Axis:"); 		
		m_DescriptionLabel = new JLabel("Description:");
			
		m_SettingsPanel.setLayout(new GridLayout(5,2,0,0));	
		m_SettingsPanel.add(m_TitleLabel);
		m_SettingsPanel.add(m_TitleField);	
		m_SettingsPanel.add(m_AuthorLabel);
		m_SettingsPanel.add(m_AuthorField);			
		m_SettingsPanel.add(m_XAxisLabel);
		m_SettingsPanel.add(m_XAxisField);			
		m_SettingsPanel.add(m_YAxisLabel);
		m_SettingsPanel.add(m_YAxisField);			
		m_SettingsPanel.add(m_DescriptionLabel);
		m_SettingsPanel.add(m_DescriptionField);	
		m_SettingsPanel.setVisible(false);
		m_ScrollPanel = new JScrollPane(m_SettingsPanel);
	}
	
	/**
	*	adds components to the tool bar
	*/
	private void initToolBar(){
		m_ToolBar = new JToolBar();
		initButtons();		
		m_ToolBar.add(m_ImpButton);
		m_ToolBar.add(m_ExpButton);
		m_ExpButton.setEnabled(false);
		m_ToolBar.addSeparator();
		m_ToolBar.add(m_TypeButton);
		m_ToolBar.addSeparator();
		m_ToolBar.add(m_SlideShowButton);
		m_ToolBar.addSeparator();
		m_ToolBar.add(m_PauseButton);
		m_SlideShowButton.setEnabled(false);
		m_PauseButton.setEnabled(false);
		m_TypeButton.setEnabled(false);
		m_ToolBar.addSeparator();
		m_ToolBar.add(m_ColourButton);
		m_ColourButton.setEnabled(false);
		m_ToolBar.addSeparator();
		m_ToolBar.add(m_EditButton);	
		m_EditButton.setEnabled(false);
		m_ToolBar.addSeparator();		
		m_ScrollPanel.setAlignmentX(Component.RIGHT_ALIGNMENT);
		add(m_ToolBar, BorderLayout.NORTH);
		m_ToolBar.setFloatable(false);	
	}

	/**
	 * @return the m_ChartPanel
	 */
	public ChartPanel GetM_ChartPanel() {
		return m_ChartPanel;
	}

	/**
	 * @param m_ChartPanel the m_ChartPanel to set
	 */
	public void SetM_ChartPanel(ChartPanel m_ChartPanel) {
		this.m_ChartPanel = m_ChartPanel;
	}

	/**
	 * @return the m_ChartPanelBottom
	 */
	public ChartPanel GetM_ChartPanelBottom() {
		return m_ChartPanelBottom;
	}

	/**
	 * @param m_ChartPanelBottom the m_ChartPanelBottom to set
	 */
	public void SetM_ChartPanelBottom(ChartPanel m_ChartPanelBottom) {
		this.m_ChartPanelBottom = m_ChartPanelBottom;
	}

	/**
	 * @return the paused
	 */
	public Boolean GetPaused() {
		return Paused;
	}

	/**
	 * @param paused the paused to set
	 */
	public void SsetPaused(Boolean paused) {
		Paused = paused;
	}

	/**
	 * @return the interval
	 */
	public int GetInterval() {
		return Interval;
	}

	/**
	 * @param interval the interval to set
	 */
	public void SetInterval(int interval) {
		Interval = interval;
	}
}