/**
 * @file Table.java
 * @author Alex Gurr
 * @brief A class that populates a table with data receieved  
 * @date 15/4/2013
 * @see GUI 
 */


 
import java.awt.BorderLayout;
import java.io.File;
import java.io.IOException;
import javax.swing.JFrame;
import javax.swing.JTable;
import javax.swing.table.DefaultTableModel;
import javax.swing.table.JTableHeader;



public class Table {
	private GUI	m_Host;
	
	/**
	* Allows the class to reference the correct instance of the main GUI
	* @param host - instance of the main GUI 
	*/

	public Table(GUI host) {
		m_Host = host;
	}

	/**
	* Returns the name of a specific column as a String, based on the column number
	* @param columnNo - the number of the column to get the heading of
	* @return columnHeading - returns the column heading as String
	*/

	public String GetColumnHeading (int columnNo) {
		String[] columnHeadings = m_Host.GetTableHeadings();
		String columnHeading = columnHeadings[columnNo];
		return columnHeading;
	}

	/**
	* Returns the height of the table
	* @return tableHeight - returns the height of the table of data as an Integer
	*/

	public int Height() {
		String[][] tempTableData = m_Host.GetTableData();
		int tableHeight = tempTableData.length;
		return tableHeight;
	}

	/**
	* Returns the width of the table
	* @return tableWidth - returns the width of the table of data as an Integer
	*/

	public int Width () {
		String[][] tempTableData = m_Host.GetTableData();
		int tableWidth = tempTableData[0].length;
		return tableWidth;
	}
	
	/**
	* Populates the table with data
	* @param dataArray - an array of Strings, with each string being a cell of data
	* @param columnHeadings - an array of String column headings
	* @return boolean - success of method
	* @return model - returns the table
	*/

	public DefaultTableModel PopulateTable (String[][] dataArray, String[] columnHeadings) {		
		DefaultTableModel model = new DefaultTableModel(dataArray, columnHeadings) {
		@Override
			public boolean isCellEditable(int row, int column) {
			return false;
			}
		};
		return model;
	}
	
	/**
	* Allows the chart classes to receive the data from the table
	* @return model - returns the current contents of the table as a type of ChartData
	*/

	public ChartData ToChartData() {
		return m_Host.GetSelectedTableData();
	}
	
}