/**	
*	@file	TypeChooser.java
*	@author	Tim Connolly
*	@date	14/04/13
*	@see	GUI, Chart, ChartData	
*
*	@brief Creates the popup interface containing the 
*	buttons for each chart type.
*
*	DisplayChartTypeChooser creates a Container, and populates it with JButtons,
*	assigning icons for each button, and putting code in the actionlisteners 
*	for these buttons to create a new graph with the data selected.
*/



import java.awt.event.ActionEvent;
import javax.swing.ImageIcon;
import java.awt.GridLayout;
import java.awt.Dimension;
import java.awt.Container;
import javax.swing.JButton;
import java.awt.event.ActionListener;
import javax.swing.JPanel;



/**
*	TypeChooser class creates an interface containing buttons for the user
*	to select which type of chart they would like to create
*/
public class TypeChooser {
	private GUI m_Host;	 								
	private JButton m_PieButton,m_HistogramButton,m_BarButton,
					m_StackedAreaButton, m_ScatterButton,m_LineButton,
					m_BarButton3D,m_PieButton3D, m_LineButton3D,
					m_StackedBarButton,m_StackedBar3DButton, m_RingButton,
					m_AreaButton,m_BubbleButton,m_XYBarButton,
					m_XYLineButton,m_MultiplePieButton,m_MultiplePie3DButton;
	
	/**
	*	Creates the interface
	*
	*	@return initContainer - Returns the components to be added to the
	*							container
	*/
	public Container CreateInterface(){
		initButtons();
		checkChartDataCompatibility();
		return initContainer();			
	}
	
	/**
	 * @return the m_Host
	 */
	public GUI Get_m_Host() {
		return m_Host;
	}

	/**
	 * @param m_Host the m_Host to set
	 */
	public void Set_m_Host(GUI m_Host) {
		this.m_Host = m_Host;
	}

	/**
	*	Construct the TypeChooser 
	*
	*	@param host is the main instance of the GUI class, containing the
	*		   methods and variables
	*/	
	public TypeChooser(GUI host){
		Set_m_Host(host);
	}		
	
	/**
	*	Adds the action listeners to each of the buttons and creates the
	*	chart when pressed, adds the chart to the left component of the
	*	split pane on the GUI
	*/
	private void addActionListeners(){
		m_PieButton.addActionListener(new ActionListener() {
       		public void actionPerformed(ActionEvent e) {
				Get_m_Host().SetChartOnPanel(new PieChart(
						   Get_m_Host().GetSelectedTableData(),
						   "Pie Chart", Get_m_Host().GetColourScheme(),
						   Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetChartOnPanelBottom(new PieChart(
						   Get_m_Host().GetSelectedTableDataLeft(),
						   "Pie Chart", Get_m_Host().GetColourScheme(),
						   Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetOptionsOnToolbar(false);
				Get_m_Host().ClearSettings();
				Get_m_Host().SetHostTitle(Get_m_Host().GetChart().GetTitle());
				Get_m_Host().closeChartDialog();
       		}
       	});	 
		m_HistogramButton.addActionListener(new ActionListener() {
       		public void actionPerformed(ActionEvent e) {
				Get_m_Host().SetChartOnPanel(new HistogramChart(
						Get_m_Host().GetSelectedTableData(),
						"Histogram Chart",
						Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetChartOnPanelBottom(new HistogramChart(
						Get_m_Host().GetSelectedTableDataLeft(),
						"Histogram Chart",
						Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetOptionsOnToolbar(true);
				Get_m_Host().ClearSettings();
				Get_m_Host().SetHostTitle(Get_m_Host().GetChart().GetTitle());
				Get_m_Host().SetHostXAxis(Get_m_Host().GetChart().GetXAxis());
				Get_m_Host().closeChartDialog();
       		}
       	});	 
		m_BarButton.addActionListener(new ActionListener() {
       		public void actionPerformed(ActionEvent e) {
				Get_m_Host().SetChartOnPanel(new BarChart(
						Get_m_Host().GetSelectedTableData(),
						"Bar Chart", Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetChartOnPanelBottom(new BarChart(
						Get_m_Host().GetSelectedTableDataLeft(),
						"Bar Chart", Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetOptionsOnToolbar(true);
				Get_m_Host().ClearSettings();
				Get_m_Host().SetHostTitle(Get_m_Host().GetChart().GetTitle());
				Get_m_Host().closeChartDialog();
       		}
       	});	 
		m_StackedAreaButton.addActionListener(new ActionListener() {
       		public void actionPerformed(ActionEvent e) {
				Get_m_Host().SetChartOnPanel(new StackedAreaChart(
						Get_m_Host().GetSelectedTableData(),
						"Stacked Area Chart",
						Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetChartOnPanelBottom(new StackedAreaChart(
						Get_m_Host().GetSelectedTableDataLeft(),
						"Stacked Area Chart",
						Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetOptionsOnToolbar(true);
				Get_m_Host().ClearSettings();
				Get_m_Host().SetHostTitle(Get_m_Host().GetChart().GetTitle());
				Get_m_Host().closeChartDialog();
       		}
       	});	 
		m_ScatterButton.addActionListener(new ActionListener() {
       		public void actionPerformed(ActionEvent e) {
				Get_m_Host().SetChartOnPanel(new ScatterChart(
						   Get_m_Host().GetSelectedTableData(),
						   "Scatter Chart", Get_m_Host().GetColourScheme(),
						   Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetChartOnPanelBottom(new ScatterChart(
						   Get_m_Host().GetSelectedTableDataLeft(),
						   "Scatter Chart", Get_m_Host().GetColourScheme(),
						   Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetOptionsOnToolbar(true);
				Get_m_Host().ClearSettings();
				Get_m_Host().SetHostTitle(Get_m_Host().GetChart().GetTitle());
				Get_m_Host().SetHostXAxis(Get_m_Host().GetChart().GetXAxis());
				Get_m_Host().SetHostYAxis(Get_m_Host().GetChart().GetYAxis());
				Get_m_Host().closeChartDialog();
       		}
       	});	 	
		m_LineButton.addActionListener(new ActionListener() {
       		public void actionPerformed(ActionEvent e) {
				Get_m_Host().SetChartOnPanel(new LineChart(
						Get_m_Host().GetSelectedTableData(),
						"Line Chart", Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetChartOnPanelBottom(new LineChart(
						Get_m_Host().GetSelectedTableDataLeft(),
						"Line Chart", Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetOptionsOnToolbar(true);
				Get_m_Host().ClearSettings();
				Get_m_Host().SetHostTitle(Get_m_Host().GetChart().GetTitle());
				Get_m_Host().closeChartDialog();
       		}
       	});	 
		m_BarButton3D.addActionListener(new ActionListener() {
       		public void actionPerformed(ActionEvent e) {
				Get_m_Host().SetChartOnPanel(new BarChart3D(
						Get_m_Host().GetSelectedTableData(),
						"Bar Chart 3D", Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetChartOnPanelBottom(new BarChart3D(
						Get_m_Host().GetSelectedTableDataLeft(),
						"Bar Chart 3D", Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetOptionsOnToolbar(true);
				Get_m_Host().ClearSettings();
				Get_m_Host().SetHostTitle(Get_m_Host().GetChart().GetTitle());
				Get_m_Host().closeChartDialog();
       		}
       	});	 
		m_PieButton3D.addActionListener(new ActionListener() {
       		public void actionPerformed(ActionEvent e) {
				Get_m_Host().SetChartOnPanel(new PieChart3D(
						Get_m_Host().GetSelectedTableData(),
						"Pie Chart 3D", Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetChartOnPanelBottom(new PieChart3D(
						Get_m_Host().GetSelectedTableDataLeft(),
						"Pie Chart 3D", Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetOptionsOnToolbar(false);
				Get_m_Host().ClearSettings();
				Get_m_Host().SetHostTitle(Get_m_Host().GetChart().GetTitle());
				Get_m_Host().closeChartDialog();
       		}
       	});	 
		m_LineButton3D.addActionListener(new ActionListener() {
       		public void actionPerformed(ActionEvent e) {
				Get_m_Host().SetChartOnPanel(new LineChart3D(
						Get_m_Host().GetSelectedTableData(),
						"Line Chart 3D",
						Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetChartOnPanelBottom(new LineChart3D(
						Get_m_Host().GetSelectedTableDataLeft(),
						"Line Chart 3D",
						Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetOptionsOnToolbar(true);
				Get_m_Host().ClearSettings();
				Get_m_Host().SetHostTitle(Get_m_Host().GetChart().GetTitle());
				Get_m_Host().closeChartDialog();
       		}
       	});	 
		m_StackedBarButton.addActionListener(new ActionListener() {
       		public void actionPerformed(ActionEvent e) {
				Get_m_Host().SetChartOnPanel(new StackedBarChart(
						Get_m_Host().GetSelectedTableData(),
						"Stacked Bar Chart",
						Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetChartOnPanelBottom(new StackedBarChart(
						Get_m_Host().GetSelectedTableDataLeft(),
						"Stacked Bar Chart",
						Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetOptionsOnToolbar(true);
				Get_m_Host().ClearSettings();
				Get_m_Host().SetHostTitle(Get_m_Host().GetChart().GetTitle());
				Get_m_Host().closeChartDialog();
       		}
       	});	 
		m_StackedBar3DButton.addActionListener(new ActionListener() {
       		public void actionPerformed(ActionEvent e) {
				Get_m_Host().SetChartOnPanel(new StackedBarChart3D(
						Get_m_Host().GetSelectedTableData(),
						"Stacked Bar Chart 3D",
						Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetChartOnPanelBottom(new StackedBarChart3D(
						Get_m_Host().GetSelectedTableDataLeft(),
						"Stacked Bar Chart 3D",
						Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetOptionsOnToolbar(true);
				Get_m_Host().ClearSettings();
				Get_m_Host().SetHostTitle(Get_m_Host().GetChart().GetTitle());
				Get_m_Host().closeChartDialog();
       		}
       	});	 
		m_RingButton.addActionListener(new ActionListener() {
       		public void actionPerformed(ActionEvent e) {
				Get_m_Host().SetChartOnPanel(new RingChart(
						Get_m_Host().GetSelectedTableData(),
						"Ring Chart", Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetChartOnPanelBottom(new RingChart(
						Get_m_Host().GetSelectedTableDataLeft(),
						"Ring Chart", Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetOptionsOnToolbar(false);
				Get_m_Host().ClearSettings();
				Get_m_Host().SetHostTitle(Get_m_Host().GetChart().GetTitle());
				Get_m_Host().closeChartDialog();
       		}
       	});	 
		m_AreaButton.addActionListener(new ActionListener() {
       		public void actionPerformed(ActionEvent e) {
				Get_m_Host().SetChartOnPanel(new AreaChart(
						Get_m_Host().GetSelectedTableData(),
						"Area Chart", Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetChartOnPanelBottom(new AreaChart(
						Get_m_Host().GetSelectedTableDataLeft(),
						"Area Chart", Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetOptionsOnToolbar(true);
				Get_m_Host().ClearSettings();
				Get_m_Host().SetHostTitle(Get_m_Host().GetChart().GetTitle());
				Get_m_Host().closeChartDialog();
       		}
       	});	 
		m_BubbleButton.addActionListener(new ActionListener() {
       		public void actionPerformed(ActionEvent e) {
				Get_m_Host().SetChartOnPanel(new BubbleChart(
						Get_m_Host().GetSelectedTableData(),
						"Bubble Chart", Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetChartOnPanelBottom(new BubbleChart(
						Get_m_Host().GetSelectedTableDataLeft(),
						"Bubble Chart", Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetOptionsOnToolbar(true);
				Get_m_Host().ClearSettings();
				Get_m_Host().SetHostTitle(Get_m_Host().GetChart().GetTitle());
				Get_m_Host().SetHostXAxis(Get_m_Host().GetChart().GetXAxis());
				Get_m_Host().SetHostYAxis(Get_m_Host().GetChart().GetYAxis());
				Get_m_Host().closeChartDialog();
       		}
       	});	 
		m_XYBarButton.addActionListener(new ActionListener() {
       		public void actionPerformed(ActionEvent e) {
				Get_m_Host().SetChartOnPanel(new XYBarChart(
										Get_m_Host().GetSelectedTableData(),
										"XY Bar Chart", Get_m_Host().GetColourScheme(),
										Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetChartOnPanelBottom(new XYBarChart(
						Get_m_Host().GetSelectedTableDataLeft(),
						"XY Bar Chart", Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetOptionsOnToolbar(true);
				Get_m_Host().ClearSettings();
				Get_m_Host().SetHostTitle(Get_m_Host().GetChart().GetTitle());
				Get_m_Host().SetHostXAxis(Get_m_Host().GetChart().GetXAxis());
				Get_m_Host().SetHostYAxis(Get_m_Host().GetChart().GetYAxis());
				Get_m_Host().closeChartDialog();
       		}
       	});	 
		m_XYLineButton.addActionListener(new ActionListener() {
       		public void actionPerformed(ActionEvent e) {
				Get_m_Host().SetChartOnPanel(new XYLineChart(
						Get_m_Host().GetSelectedTableData(),
						"XY Line Chart",
						Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetChartOnPanelBottom(new XYLineChart(
						Get_m_Host().GetSelectedTableDataLeft(),
						"XY Line Chart",
						Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetOptionsOnToolbar(true);
				Get_m_Host().ClearSettings();
				Get_m_Host().SetHostTitle(Get_m_Host().GetChart().GetTitle());
				Get_m_Host().SetHostXAxis(Get_m_Host().GetChart().GetXAxis());
				Get_m_Host().SetHostYAxis(Get_m_Host().GetChart().GetYAxis());
				Get_m_Host().closeChartDialog();
       		}
       	});	 
		m_MultiplePieButton.addActionListener(new ActionListener() {
       		public void actionPerformed(ActionEvent e) {
				Get_m_Host().SetChartOnPanel(new MultiplePieChart(
										Get_m_Host().GetSelectedTableData(),
										"Multiple Pie Chart",
										Get_m_Host().GetColourScheme(),
										Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetChartOnPanelBottom(new MultiplePieChart(
						Get_m_Host().GetSelectedTableDataLeft(),
						"Multiple Pie Chart",
						Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetOptionsOnToolbar(false);
				Get_m_Host().ClearSettings();
				Get_m_Host().SetHostTitle(Get_m_Host().GetChart().GetTitle());
				Get_m_Host().closeChartDialog();
       		}
       	});	 
		m_MultiplePie3DButton.addActionListener(new ActionListener() {
       		public void actionPerformed(ActionEvent e) {
				Get_m_Host().SetChartOnPanel(new MultiplePieChart3D(
						Get_m_Host().GetSelectedTableData(),
						"Multiple Pie Chart 3D",
						Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetChartOnPanelBottom(new MultiplePieChart3D(
						Get_m_Host().GetSelectedTableDataLeft(),
						"Multiple Pie Chart 3D",
						Get_m_Host().GetColourScheme(),
						Get_m_Host().GetUserDefinedScheme()));
				Get_m_Host().SetOptionsOnToolbar(false);
				Get_m_Host().ClearSettings();
				Get_m_Host().SetHostTitle(Get_m_Host().GetChart().GetTitle());
				Get_m_Host().closeChartDialog();
       		}
       	});	
	}
	
	/**
	*	enables certain buttons depending on what data has been selected
	*/
	private void checkChartDataCompatibility(){
		ChartData dataToCheckButtons = Get_m_Host().GetSelectedTableData();
		switch (dataToCheckButtons.Height()){
		case 1 : 	m_ScatterButton.setEnabled(false);
					m_LineButton.setEnabled(false);
					m_LineButton3D.setEnabled(false);
					m_XYLineButton.setEnabled(false);
					m_XYBarButton.setEnabled(false);
					m_BubbleButton.setEnabled(false);
					//m_MultiplePieButton.setEnabled(false);
					//m_MultiplePie3DButton.setEnabled(false);
					break;
		case 2 :	m_BubbleButton.setEnabled(false);
					m_HistogramButton.setEnabled(false);
					m_RingButton.setEnabled(false);
					m_PieButton.setEnabled(false);
					m_PieButton3D.setEnabled(false);
					break;
		case 3 :	//m_ScatterButton.setEnabled(false);
					//m_XYLineButton.setEnabled(false);
					//m_XYBarButton.setEnabled(false);
					m_HistogramButton.setEnabled(false);
					m_RingButton.setEnabled(false);
					m_PieButton.setEnabled(false);
					m_PieButton3D.setEnabled(false);
					break;
		default :	m_BubbleButton.setEnabled(false);
					//m_ScatterButton.setEnabled(false);
					//m_XYLineButton.setEnabled(false);
					//m_XYBarButton.setEnabled(false);
					m_HistogramButton.setEnabled(false);
					m_RingButton.setEnabled(false);
					m_PieButton.setEnabled(false);
					m_PieButton3D.setEnabled(false);
					break;
		}
	}

	/**
	*	Construct the Buttons within the interface
	*/
	private void initButtons(){
		m_PieButton = new JButton(new ImageIcon(ClassLoader.getSystemResource("pie_chart.jpg")));
		m_PieButton.setToolTipText("Pie Chart");
		m_HistogramButton = new JButton(new ImageIcon(ClassLoader.getSystemResource("histogram.jpg")));
		m_HistogramButton.setToolTipText("Histogram");
		m_BarButton = new JButton(new ImageIcon(ClassLoader.getSystemResource("bar_chart.jpg")));
		m_BarButton.setToolTipText("Bar Chart");
		m_StackedAreaButton = new JButton(new ImageIcon(
				ClassLoader.getSystemResource("stacked_area.jpg")));
		m_StackedAreaButton.setToolTipText("Stacked Area Graph");
		m_ScatterButton = new JButton(new ImageIcon(ClassLoader.getSystemResource("scatter.jpg")));
		m_ScatterButton.setToolTipText("Scatter Graph");
		m_LineButton = new JButton(new ImageIcon(ClassLoader.getSystemResource("line.jpg")));
		m_LineButton.setToolTipText("Line Graph");
		m_BarButton3D = new JButton(new ImageIcon(ClassLoader.getSystemResource("3d_bar_chart.jpg")));
		m_BarButton3D.setToolTipText("3D Bar Chart");
		m_PieButton3D = new JButton(new ImageIcon(ClassLoader.getSystemResource("3d_pie_chart.jpg")));
		m_PieButton3D.setToolTipText("3D Pie Chart");
		m_LineButton3D = new JButton(new ImageIcon(ClassLoader.getSystemResource("linechart3d.jpg")));
		m_LineButton3D.setToolTipText("3D Line Chart");
		m_StackedBarButton = new JButton(new ImageIcon(ClassLoader.getSystemResource("stackedbar.jpg")));
		m_StackedBarButton.setToolTipText("Stacked Bar Chart");
		m_StackedBar3DButton = new JButton(new ImageIcon(
				ClassLoader.getSystemResource("stackedbarchart3d.jpg")));
		m_StackedBar3DButton.setToolTipText("3D Stacked Bar Chart");
		m_RingButton = new JButton(new ImageIcon(
				ClassLoader.getSystemResource("ringchart.jpg")));
		m_RingButton.setToolTipText("Ring Chart");
		m_AreaButton = new JButton(new ImageIcon(
				ClassLoader.getSystemResource("areachart.jpg")));
		m_AreaButton.setToolTipText("Area Chart");
		m_BubbleButton = new JButton(new ImageIcon(
				ClassLoader.getSystemResource("bubblechart.jpg")));
		m_BubbleButton.setToolTipText("Bubble Chart");
		m_XYBarButton = new JButton(new ImageIcon(
				ClassLoader.getSystemResource("xybarchart.jpg")));
		m_XYBarButton.setToolTipText("XY Bar Chart");
		m_XYLineButton = new JButton(new ImageIcon(
				ClassLoader.getSystemResource("xylinechart.jpg")));
		m_XYLineButton.setToolTipText("XY Line Chart");
		m_MultiplePieButton = new JButton(new ImageIcon(
				ClassLoader.getSystemResource("multiplepie.jpg")));
		m_MultiplePieButton.setToolTipText("Multiple Pie Chart");
		m_MultiplePie3DButton = new JButton(new ImageIcon(
				ClassLoader.getSystemResource("multiplepiechart3d.jpg")));
		m_MultiplePie3DButton.setToolTipText("3D Multiple Pie Chart");
		addActionListeners();
	}
	
	/**
	*	adds the buttons to the container
	*
	*	@return chartTypeInterface - returns the container
	*/
	private Container initContainer(){
		Container chartTypeInterface;
		chartTypeInterface = new Container();
		chartTypeInterface.setLayout(new GridLayout(3,6,0,0));	
		
		chartTypeInterface.add(m_PieButton);		
		chartTypeInterface.add(m_BarButton);
		chartTypeInterface.add(m_HistogramButton);
		chartTypeInterface.add(m_StackedAreaButton);
		chartTypeInterface.add(m_ScatterButton);
		chartTypeInterface.add(m_LineButton);
		chartTypeInterface.add(m_BarButton3D);
		chartTypeInterface.add(m_PieButton3D);
		chartTypeInterface.add(m_LineButton3D);
		chartTypeInterface.add(m_StackedBarButton);
		chartTypeInterface.add(m_StackedBar3DButton);
		chartTypeInterface.add(m_RingButton);
		chartTypeInterface.add(m_AreaButton);
		chartTypeInterface.add(m_BubbleButton);
		chartTypeInterface.add(m_XYBarButton);
		chartTypeInterface.add(m_XYLineButton);
		chartTypeInterface.add(m_MultiplePieButton);
		chartTypeInterface.add(m_MultiplePie3DButton);
		
		return chartTypeInterface;
	}
}